# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support
%bcond_with maven
%bcond_without repolib

%define repodir %{_javadir}/repository.jboss.com/apache-%{base_name}/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define base_name  discovery
%define short_name commons-%{base_name}
%define section    free

Name:           jakarta-commons-discovery
Version:        0.4
Release:        7%{?dist}
Epoch:          1
Summary:        Jakarta Commons Discovery
Group:          Development/Libraries/Java
License:        ASL 2.0
URL:            http://jakarta.apache.org/commons/discovery/
Source0:        http://www.apache.org/dist/jakarta/commons/discovery/source/commons-discovery-0.4-src.tar.gz
Source1:        http://mirrors.ibiblio.org/pub/mirrors/maven2/commons-discovery/commons-discovery/0.4/commons-discovery-0.4.pom
Source2:        jakarta-commons-discovery-component-info.xml
Provides:       %{short_name} = %{epoch}:%{version}-%{release}
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:       jakarta-commons-logging >= 0:1.0.4
BuildRequires:  jpackage-utils
BuildRequires:  ant
BuildRequires:  junit >= 0:3.7
BuildRequires:  jakarta-commons-logging >= 0:1.0.4
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
BuildArch:      noarch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
The Discovery component is about discovering, or finding, implementations for
pluggable interfaces.  Pluggable interfaces are specified with the intent that
multiple implementations are, or will be, available to provide the service
described by the interface.  Discovery provides facilities for finding and
instantiating classes, and for lifecycle management of singleton (factory)
classes. 

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%package javadoc
Group:          Development/Documentation
Summary:        Javadoc for %{name}
Provides:       %{short_name}-javadoc = %{epoch}:%{version}-%{release}

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n commons-discovery-%{version}-src

%build
export OPT_JAR_LIST=:
export CLASSPATH=
%{ant} \
  -Djunit.jar=%(find-jar junit) \
  -Dlogger.jar=%(find-jar jakarta-commons-logging) \
  test.discovery dist

%install
%{__rm} -rf %{buildroot}

# jar
%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -p dist/%{short_name}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
(cd %{buildroot}%{_javadir} && %{__ln_s} %{name}-%{version}.jar %{short_name}-%{version}.jar && for jar in *-%{version}.jar; do %{__ln_s} ${jar} `/bin/echo ${jar} | %{__sed} "s|-%{version}||g"`; done)

# javadoc
%{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__cp} -pr dist/docs/api/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__ln_s} %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}
%{__ln_s} %{name}-%{version} %{buildroot}%{_javadocdir}/%{short_name}-%{version}
%{__ln_s} %{short_name}-%{version} %{buildroot}%{_javadocdir}/%{short_name}

# pom
%{__mkdir_p} %{buildroot}%{_datadir}/maven2/poms
%{__cp} -p %{SOURCE1} %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap commons-discovery commons-discovery %{version} JPP %{name}

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%if %with repolib
%{__mkdir_p} %{buildroot}%{repodir}
%{__mkdir_p} %{buildroot}%{repodirlib}
%{__cp} -p %{SOURCE2} %{buildroot}%{repodir}/component-info.xml
tag=`/bin/echo %{name}-%{version}-%{release} | %{__sed} 's|\.|_|g'`
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%{__sed} -i s/@VERSION@/%{version}-brew/g %{buildroot}%{repodir}/component-info.xml
%{__mkdir_p} %{buildroot}%{repodirsrc}
%{__cp} -p %{SOURCE0} %{buildroot}%{repodirsrc}
%{__cp} -p %{buildroot}%{_javadir}/commons-discovery.jar %{buildroot}%{repodirlib}/commons-discovery.jar
%{__cp} -p %{SOURCE1} %{buildroot}%{repodirlib}/commons-discovery.pom
%endif

%clean
%{__rm} -rf %{buildroot}

%post
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif
%update_maven_depmap

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%doc LICENSE.txt NOTICE.txt
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_javadir}/%{short_name}-%{version}.jar
%{_javadir}/%{short_name}.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}
%if %{gcj_support}
%fir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/jakarta-commons-discovery-%{version}.jar.*
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}
%{_javadocdir}/%{short_name}-%{version}
%{_javadocdir}/%{short_name}

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%{_javadir}/repository.jboss.com
%endif

%changelog
* Tue Oct 06 2009 David Walluck <dwalluck@redhat.com> 0:1.0.4-7
- add pom
- add commons-discovery Provides and javadoc symlinks
- fix GCJ file list
- copy pom to repolib
- fix with repolib

* Tue May 19 2009 David Walluck <dwalluck@redhat.com> 0:1.0.4-6
- fix repolib version

* Tue May 19 2009 David Walluck <dwalluck@redhat.com> 0:1.0.4-5
- fix repolib

* Wed Apr 08 2009 David Walluck <dwalluck@redhat.com> 0:1.0.4-4
- fix file list

* Fri May 30 2008 Permaine Cheung <pcheung@redhat.com> - 1:0.4-3
- First JPP5 build

* Sat Feb 17 2007 Fernando Nasser <fnasser@redhat.com> - 1:0.4-2jpp
- Remove distribution and vendor tags
- Fix empty post postun messages
- Use spaces and no tabs all over

* Sat Feb 17 2007 Fernando Nasser <fnasser@redhat.com> - 1:0.4-1jpp
- Upgrade to 0.4
- New license is ASL 2
- Add NOTICE.txt real file

* Thu Aug 10 2006 Matt Wringe <mwringe at redhat.com> - 1:0:3-4jpp
- Add missing javadoc post and postun
- Add missing javadoc requires

* Thu Jul 20 2006 Matt Wringe <mwringe at redhat.com> - 1:0:3-3jpp
- Added conditional native compiling

* Thu Apr 26 2006 Fernando Nasser <fnasser@redhat.com> - 1:0.3-2jpp
- First JPP 1.7 build

* Sat Jun 04 2005 Fernando Nasser <fnasser@redhat.com> - 1:1:0.3-1jpp_1rh
- Merge for update

* Sat Jun 04 2005 Fernando Nasser <fnasser@redhat.com> - 1:1:0.3-1jpp
- Update to 0.3

* Wed Nov 03 2004 Fernando Nasser <fnasser@redhat.com> 0:4.1.29-2jpp_2rh
- Rebuild

* Sun Aug 23 2004 Randy Watler <rwatler at finali.com> - 1:0.2-2jpp
- Rebuild with ant-1.6.2

* Thu Mar  4 2004 Frank Ch. Eigler <fche@redhat.com> 1:1.0-1jpp_1rh
- RH vacuuming

* Thu Apr 17 2003 Ville Skyttä <ville.skytta at iki.fi> - 1:0.2-1jpp
- Update to 0.2 and JPackage 1.5.

* Fri Sep 13 2002 Ville Skyttä <ville.skytta at iki.fi> 1:0.1-1jpp
- 0.1.

* Sat Sep  7 2002 Ville Skyttä <ville.skytta at iki.fi> 1.0-0.rc1.1jpp
- First JPackage release.

